@@ -1,5 +1,5 @@
 package Class::Container;
-$VERSION = '0.01_02';
+$VERSION = '0.01_03';
 $VERSION = eval $VERSION;
 
 use strict;
@@ -176,6 +176,7 @@ sub create_delayed_object
     my $class = $self->{"_delayed_$name"}{class}
 	or ParamError->throw(error => "Unknown class for delayed object '$name'");
 
+    $self->_load_module($class);
     return $class->new( %{ $self->{"_delayed_$name"}{args} }, %args );
 }
 
@@ -201,12 +202,7 @@ sub _get_contained_args
     ParamError->throw(error => "Invalid class name '$contained_class'")
 	unless $contained_class =~ /^[\w:]+$/;
 
-    unless ( eval { $contained_class->can('new') } )
-    {
-	no strict 'refs';
-	eval "use $contained_class";
-	GenericError->throw(error => $@) if $@;
-    }
+    $class->_load_module($contained_class);
 
     return {} unless $contained_class->can('allowed_params');
 
@@ -236,6 +232,17 @@ sub _make_contained_object
     return $contained_class->new(%$contained_args);
 }
 
+sub _load_module {
+    my ($self, $module) = @_;
+    
+    unless ( eval { $module->can('new') } )
+    {
+	no strict 'refs';
+	eval "use $module";
+	GenericError->throw(error => $@) if $@;
+    }
+}
+
 # Iterate through this object's @ISA and find all entries in
 # 'contained_objects' list.  Return as a hash.
 sub get_contained_objects
@@ -288,12 +295,7 @@ sub allowed_params
 
 	# we have to make sure it is loaded before we try calling
 	# ->allowed_params
-	unless ( eval { $contained_class->can('new') } )
-	{
-	    eval "use $contained_class";
-	    GenericError->throw(error => $@) if $@;
-	}
-
+	$class->_load_module($contained_class);
 	next unless $contained_class->can('allowed_params');
 
 	my $subparams = $contained_class->allowed_params($args);
